@@ -52,7 +52,7 @@ class _Header(ctypes.Structure):
         ('tMax', ctypes.c_double),
         ('yMin', ctypes.c_double),
         ('delta', ctypes.c_double),
-        ('void', ctypes.c_char_p)
+        ('void', ctypes.c_char * 8)
     ]
 
 
